mercurial/revset.py
changeset 15135 f19de58af225
parent 15134 81adf7777f8f
child 15136 18219c0789ae
--- a/mercurial/revset.py	Sun Sep 18 22:54:11 2011 +0200
+++ b/mercurial/revset.py	Sat Sep 17 00:20:45 2011 +0200
@@ -237,13 +237,10 @@
 
 def bisect(repo, subset, x):
     """``bisect(string)``
     Changesets marked in the specified bisect state (good, bad, skip).
     """
-    state = getstring(x, _("bisect requires a string")).lower()
-    if state not in ('good', 'bad', 'skip'):
-        raise error.ParseError(_('invalid bisect state'))
-    marked = set(repo.changelog.rev(n) for n in hbisect.load_state(repo)[state])
-    return [r for r in subset if r in marked]
+    status = getstring(x, _("bisect requires a string")).lower()
+    return [r for r in subset if r in hbisect.get(repo, status)]
 
 # Backward-compatibility
 # - no help entry so that we do not advertise it any more
@@ -237,13 +237,10 @@
 def bisect(repo, subset, x):
     """``bisect(string)``
-    Changesets marked in the specified bisect state (good, bad, skip).
+    Changesets marked in the specified bisect status (good, bad, skip).
     """